@@ -6,7 +6,7 @@ use Exporter 'import';
 our @ISA;
 our $VERSION;
 BEGIN {
-	$VERSION = '0.17';
+	$VERSION = '0.18';
 
 	my $loaded = 0;
 
@@ -28,9 +28,6 @@ BEGIN {
 		$load_dyna->() if $@;
 	}
 }
-END {
-	_global_cleanup();
-}
 
 our @EXPORT_OK = grep /^(?:LIB)?CURL/, keys %{WWW::CurlOO::};
 our %EXPORT_TAGS = ( constants => \@EXPORT_OK );
