@@ -10,6 +10,15 @@ use Exporter 'import';
 our @EXPORT_OK = grep /^CURL/, keys %{WWW::CurlOO::Multi::};
 our %EXPORT_TAGS = ( constants => \@EXPORT_OK );
 
+# workaround for "magical destroy too late" bug
+sub DESTROY
+{
+	my $self = shift;
+	foreach my $easy ( $self->handles() ) {
+		$self->remove_handle( $easy );
+	}
+}
+
 package WWW::CurlOO::Multi::Code;
 
 use overload
@@ -242,7 +251,7 @@ Socket callback will be called only if socket_action() method is being used.
 It receives 6 arguments: multi handle, easy handle, socket file number, poll
 action, socket data (see assign), and CURLMOPT_SOCKETDATA value. It must
 return 0.
-For more information reffer to L<curl_multi_socket_action(3)>.
+For more information refer to L<curl_multi_socket_action(3)>.
 
  sub cb_socket {
      my ( $multi, $easy, $socketfn, $action, $socketdata, $uservar ) = @_;
